@@ -24,14 +24,12 @@ class Worker(Process):
         super().__init__()
         self.input_queue = input_frames
         self.result_queue = result_queue
-        self.model_loaded = False
         self.model = None
 
     def predict(self,Eye):
-        if not self.model_loaded:
+        if self.model is None:
             from keras.models import load_model
-            self.model = load_model(os.path.join(Path(__file__).parent, 'cnnCat2.h5'))
-            self.model_loaded = True
+            self.model = load_model(os.path.join(Path(__file__).parent, 'cnnCat3.h5'))
 
         if Eye is None:
             # eyes are not detected so effectively we can consider this case as drowsy
@@ -50,9 +48,18 @@ class Worker(Process):
                 print(worker_result)
                 self.result_queue.put(worker_result)
 
+    def adjust_gamma(self,image, gamma=1.0):
+
+        invGamma = 1.0 / gamma
+        table = np.array([((i / 255.0) ** invGamma) * 255
+                          for i in np.arange(0, 256)]).astype("uint8")
+
+        return cv2.LUT(image, table)
 
     def process(self,frame):
         gray = cv2.cvtColor(frame, cv2.COLOR_BGR2GRAY)
+        gray = cv2.equalizeHist(gray)
+        gray = self.adjust_gamma(gray,gamma=1.5)
         left_eyes = self.__class__.LeftEye.detectMultiScale(gray)
         right_eyes = self.__class__.RightEye.detectMultiScale(gray)
 
@@ -60,19 +67,17 @@ class Worker(Process):
 
         for (x, y, w, h) in right_eyes:
             result.RightEye = (x,y,w,h)
-            r_eye = frame[y:y + h, x:x + w]
-            right_eyes = cv2.cvtColor(r_eye, cv2.COLOR_BGR2GRAY)
+            right_eyes = gray[y:y + h, x:x + w]
             break
 
         for (x, y, w, h) in left_eyes:
             result.LeftEye = (x,y,w,h)
-            l_eye = frame[y:y + h, x:x + w]
-            left_eyes = cv2.cvtColor(l_eye, cv2.COLOR_BGR2GRAY)
+            left_eyes = gray[y:y + h, x:x + w]
             break
 
         l = self.process_single_eye(right_eyes)
         r = self.process_single_eye(left_eyes)
-        result.OpenProbability = self.predict(l) and self.predict(r)
+        result.OpenProbability = self.predict(l) or self.predict(r)
         return result
 
     def process_single_eye(self,eye):
